import os

JWKS_ENDPOINT = os.getenv("JWKS_ENDPOINT", "http://nginx/api/tokens/jwks")
JWT_ALGORITHM = "RS256"
HOST_RESOURCE_APP = os.getenv("HOST_RESOURCE_APP")

if HOST_RESOURCE_APP is None:
    raise Exception("環境変数 HOST_RESOURCE_APP は必須です。")

JWT_AUDIENCE = [HOST_RESOURCE_APP]



from setuptools import setup, find_packages

setup(
    name='teppen-fastauth',
    version='0.1.1',
    author='Yasufumi Kamiyama',
    description='Authentication Library for FastAPI',
    packages=find_packages(),
    install_requires=[
        'fastapi',
        'pydantic',
        'PyJWT',
        'cryptography',
    ],
    license='MIT',
)
